import axios from 'axios';
import * as QueryString from 'querystring';
import { ImageRequest } from './PixabayRequest';
import { ImageResponse } from './PixabayResponse';
import { validateRequest } from './ValidateRequest';

const PIXABAY_URL = 'https://pixabay.com/api/?';

/**
 * Search for image on pixabay
 * @param key - you can obtain your authentication key by sign up on pixabay
 * @param searchQuery - search for image names, should not exceed 100 characters
 * @param request - pixabay request
 * @param validate - should validate request ? It'll throw an error if validation fail
 */
const searchImagesRequest = async (key: string, searchQuery: string, options: ImageRequest = {}, validate = true) => {
    options.q = QueryString.stringify(searchQuery);
    options.key = key;
    if (validate) {
        validateRequest(options);
    }
    const response = (await axios.post(PIXABAY_URL + QueryString.stringify(options))).data;
    if (!response.hits && !response.total && !response.totalHits) {
        // TODO: more descriptive error
        throw new Error(`Bad response, 'response.hits', 'response.total' or 'response.totalHits' is missing`);
    }
    return response as ImageResponse;
};

// TODO: Add  search video request

/**
 * Authenticate user. You'll no longer need to write auth key on every request call
 * @param key - you can obtain your key by sign up on pixabay
 */
export const authenticate = (key: string) => ({
    /**
     * Search for image son pixabay
     * @param request - pixabay request
     * @param validate - should validate request ? It'll throw an error if validation fail
     */
    searchImages: async (searchQuery: string, request: ImageRequest = {}, validate: boolean = true) =>
        await searchImagesRequest(key, searchQuery, request, validate),
    // TODO: Add search for videos request
    // searchVideosRequest:
});

// export const searchVideos = searchVideosRequest;

export const searchImages = searchImagesRequest;
